@@ -123,6 +123,17 @@ func cmdDel(args *skel.CmdArgs) error {
 		return nil
 	})
 
+	if err != nil {
+		//  if NetNs is passed down by the Cloud Orchestration Engine, or if it called multiple times
+		// so don't return an error if the device is already removed.
+		// https://github.com/kubernetes/kubernetes/issues/43014#issuecomment-287164444
+		_, ok := err.(ns.NSPathNotExistErr)
+		if ok {
+			return nil
+		}
+		return err
+	}
+
 	if err != nil {
 		return fmt.Errorf("cmdDel failed: %v", err)
 	}
